/* $Id: ApplicationS.h,v 1.2 1999/01/14 03:08:53 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_APPLICATIONS_H_)
#define _XARM_APPLICATIONS_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Shell.h>

class ApplicationShellClass : public TopLevelShellClass {
 protected:
   ApplicationShellClass() {}

   virtual WidgetClass classPointer() { return applicationShellWidgetClass; }
   virtual _XtString className() { return (_XtString) "ApplicationShell"; }
 public:
   int argc() const;
   void argc(int);
   _XtString *argv() const;
   void argv(const _XtString *);
};

#endif
